@@ -97,9 +97,6 @@ from cutadapt.pipeline import (
     PairedEndPipeline,
     InputPaths,
     OutputFiles,
-    PipelineRunner,
-    SerialPipelineRunner,
-    ParallelPipelineRunner,
 )
 from cutadapt.utils import available_cpu_count, Progress, DummyProgress, FileOpener
 from cutadapt.log import setup_logging, REPORT
@@ -239,12 +236,12 @@ def get_argument_parser() -> ArgumentParser:
         help=SUPPRESS)  # Deprecated, use --action=mask
 
     group = parser.add_argument_group("Additional read modifications")
-    group.add_argument("-u", "--cut", action='append', default=[], type=int, metavar="LENGTH",
-        help="Remove bases from each read (first read only if paired). "
-            "If LENGTH is positive, remove bases from the beginning. "
-            "If LENGTH is negative, remove bases from the end. "
-            "Can be used twice if LENGTHs have different signs. "
-            "This is applied *before* adapter trimming.")
+    group.add_argument("-u", "--cut", action='append', default=[], type=int, metavar="LEN",
+        help="Remove LEN bases from each read (or R1 if paired; use -U option for R2). "
+            "If LEN is positive, remove bases from the beginning. "
+            "If LEN is negative, remove bases from the end. "
+            "Can be used twice if LENs have different signs. "
+            "Applied *before* adapter trimming.")
     group.add_argument("--nextseq-trim", type=int, default=None, metavar="3'CUTOFF",
         help="NextSeq-specific quality trimming (each read). Trims also dark "
             "cycles appearing as high-quality G bases.")
@@ -554,6 +551,9 @@ def open_output_files(
 
 
 def complain_about_duplicate_paths(paths: List[str]):
+    if sys.platform == "win32" and sys.version_info < (3, 8):
+        # Bug in handling of NUL
+        return
     seen = set()
     for path in paths:
         if path is None:
@@ -881,8 +881,12 @@ def adapters_from_args(args) -> Tuple[List[Adapter], List[Adapter]]:
     try:
         adapters = make_adapters_from_specifications(args.adapters, search_parameters)
         adapters2 = make_adapters_from_specifications(args.adapters2, search_parameters)
-    except (FileNotFoundError, ValueError, InvalidCharacter) as e:
-        raise CommandLineError(e)
+    except (
+        KeyError,
+        ValueError,
+        InvalidCharacter,
+    ) as e:
+        raise CommandLineError(e.args[0])
     warn_duplicate_adapters(adapters)
     warn_duplicate_adapters(adapters2)
     if args.debug > 1:
@@ -1081,36 +1085,31 @@ def main(cmdlineargs, default_outfile=sys.stdout.buffer) -> Statistics:
             path2=input_paired_filename,
             interleaved=is_interleaved_input,
         )
-        runner = setup_runner(
-            pipeline, inpaths, outfiles, progress, cores, args.buffer_size, file_opener
+        logger.info(
+            "Processing %s reads on %d core%s ...",
+            {False: "single-end", True: "paired-end"}[pipeline.paired],
+            cores,
+            "s" if cores > 1 else "",
         )
-    except CommandLineError as e:
-        logger.debug("Command line error. Traceback:", exc_info=True)
-        parser.error(str(e))
-        return
+        stats = pipeline.run(inpaths, outfiles, cores, progress, args.buffer_size)
 
-    logger.info(
-        "Processing %s reads on %d core%s ...",
-        {False: "single-end", True: "paired-end"}[pipeline.paired],
-        cores,
-        "s" if cores > 1 else "",
-    )
-    try:
-        with runner as r:
-            stats = r.run()
     except KeyboardInterrupt:
         print("Interrupted", file=sys.stderr)
         sys.exit(130)
     except BrokenPipeError:
         sys.exit(1)
     except (
-        dnaio.FileFormatError,
-        dnaio.UnknownFileFormat,
+        OSError,
         EOFError,
         HasNoQualities,
+        dnaio.UnknownFileFormat,
+        dnaio.FileFormatError,
+        CommandLineError,
     ) as e:
         logger.debug("Command line error. Traceback:", exc_info=True)
-        sys.exit(f"cutadapt: error: {e}")
+        logger.error("%s", e)
+        exit_code = 2 if isinstance(e, CommandLineError) else 1
+        sys.exit(exit_code)
 
     elapsed = time.time() - start_time
     if args.report == "minimal":
@@ -1123,7 +1122,8 @@ def main(cmdlineargs, default_outfile=sys.stdout.buffer) -> Statistics:
             json_dict = json_report(
                 stats=stats,
                 cmdlineargs=cmdlineargs,
-                inpaths=inpaths,
+                path1=inpaths.path1,
+                path2=inpaths.path2,
                 cores=cores,
                 paired=paired,
                 gc_content=args.gc_content / 100.0,
@@ -1155,33 +1155,6 @@ def log_adapters(adapters, adapters2):
             logger.debug("- %s", a)
 
 
-def setup_runner(
-    pipeline: Pipeline,
-    inpaths: InputPaths,
-    outfiles: OutputFiles,
-    progress: Progress,
-    cores: int,
-    buffer_size: int,
-    file_opener: FileOpener,
-) -> PipelineRunner:
-    try:
-        if cores > 1:
-            return ParallelPipelineRunner(
-                pipeline,
-                inpaths,
-                outfiles,
-                file_opener,
-                progress,
-                n_workers=cores,
-                buffer_size=buffer_size,
-            )
-        else:
-            infiles = inpaths.open(file_opener)
-            return SerialPipelineRunner(pipeline, infiles, outfiles, progress)
-    except (dnaio.UnknownFileFormat, dnaio.FileFormatError, OSError) as e:
-        raise CommandLineError(e)
-
-
 def setup_profiler_if_requested(requested):
     if requested:
         import cProfile
@@ -1230,7 +1203,8 @@ def is_any_output_stdout(args):
 def json_report(
     stats: Statistics,
     cmdlineargs: List[str],
-    inpaths: InputPaths,
+    path1: str,
+    path2: Optional[str],
     cores: int,
     paired: bool,
     gc_content: float,
@@ -1243,8 +1217,8 @@ def json_report(
         "command_line_arguments": cmdlineargs,
         "cores": cores,
         "input": {
-            "path1": inpaths.path1,
-            "path2": inpaths.path2,
+            "path1": path1,
+            "path2": path2,
             "paired": paired,
         },
     }
