@@ -9,7 +9,7 @@ from types import SimpleNamespace
 from typing import Sequence, List, Tuple, Optional, Set
 from abc import ABC, abstractmethod
 
-from dnaio import record_names_match, Sequence as SequenceRecord
+from dnaio import record_names_match, SequenceRecord
 
 from .qualtrim import quality_trim_index, nextseq_trim_index
 from .adapters import (
@@ -22,7 +22,7 @@ from .adapters import (
     Adapter,
 )
 from .tokenizer import tokenize_braces, TokenizeError, Token, BraceToken
-from .utils import reverse_complemented_sequence
+from .info import ModificationInfo
 
 logger = logging.getLogger()
 
@@ -31,43 +31,20 @@ logger = logging.getLogger()
 INDEXING_THRESHOLD = 5
 
 
-class ModificationInfo:
-    """
-    An object of this class is created for each read that passes through the pipeline.
-    Any information (except the read itself) that needs to be passed from one modifier
-    to one later in the pipeline or from one modifier to the filters is recorded here.
-    """
-
-    __slots__ = ["matches", "original_read", "cut_prefix", "cut_suffix", "is_rc"]
-
-    def __init__(self, read):
-        self.matches: List[Match] = []
-        self.original_read = read
-        self.cut_prefix = None
-        self.cut_suffix = None
-        self.is_rc = None
-
-    def __repr__(self):
-        return (
-            "ModificationInfo("
-            f"matches={self.matches!r}, "
-            f"original_read={self.original_read}, "
-            f"cut_prefix={self.cut_prefix}, "
-            f"cut_suffix={self.cut_suffix}, "
-            f"is_rc={self.is_rc})"
-        )
-
-
 class SingleEndModifier(ABC):
     @abstractmethod
-    def __call__(self, read, info: ModificationInfo):
+    def __call__(self, read: SequenceRecord, info: ModificationInfo):
         pass
 
 
 class PairedEndModifier(ABC):
     @abstractmethod
     def __call__(
-        self, read1, read2, info1: ModificationInfo, info2: ModificationInfo
+        self,
+        read1: SequenceRecord,
+        read2: SequenceRecord,
+        info1: ModificationInfo,
+        info2: ModificationInfo,
     ) -> Tuple[SequenceRecord, SequenceRecord]:
         pass
 
@@ -107,8 +84,17 @@ class PairedEndModifierWrapper(PairedEndModifier):
 class AdapterCutter(SingleEndModifier):
     """
     Repeatedly find one of multiple adapters in reads.
-    The number of times the search is repeated is specified by the
-    times parameter.
+
+    Arguments:
+        adapters: Adapters to be searched
+        times: Repeat the search this number of times.
+        action: What to do with a found adapter.
+            - *None*: Do nothing, only update the ModificationInfo appropriately
+            - "trim": Remove the adapter and down- or upstream sequence depending on adapter type
+            - "mask": Replace the part of the sequence that would have been removed with "N" bases
+            - "lowercase": Convert the part of the sequence that would have been removed to lowercase
+            - "retain": Like "trim", but leave the adapter sequence itself in the read
+        index: If True, attempt to create an index to speed up the search (if possible)
     """
 
     def __init__(
@@ -118,16 +104,6 @@ class AdapterCutter(SingleEndModifier):
         action: Optional[str] = "trim",
         index: bool = True,
     ):
-        """
-        action -- What to do with a found adapter:
-          None: Do nothing, only update the ModificationInfo appropriately
-          "trim": Remove the adapter and down- or upstream sequence depending on adapter type
-          "mask": Replace the part of the sequence that would have been removed with "N" bases
-          "lowercase": Convert the part of the sequence that would have been removed to lowercase
-          "retain": Like "trim", but leave the adapter sequence itself in the read
-
-        index -- if True, an adapter index (for multiple adapters) is created if possible
-        """
         self.times = times
         assert action in ("trim", "mask", "lowercase", "retain", None)
         self.action = action
@@ -294,8 +270,8 @@ class ReverseComplementer(SingleEndModifier):
     def __repr__(self):
         return f"ReverseComplementer(adapter_cutter={self.adapter_cutter})"
 
-    def __call__(self, read, info: ModificationInfo):
-        reverse_read = reverse_complemented_sequence(read)
+    def __call__(self, read: SequenceRecord, info: ModificationInfo):
+        reverse_read = read.reverse_complement()
 
         forward_trimmed_read, forward_matches = self.adapter_cutter.match_and_trim(read)
         reverse_trimmed_read, reverse_matches = self.adapter_cutter.match_and_trim(
@@ -550,10 +526,43 @@ class Renamer(SingleEndModifier):
             raise InvalidTemplate(f"Error in template '{template}': {e}")
         self.raise_if_invalid_variable(self._tokens, self.variables)
         self._template = template
+        self._rename = self.compile_rename_function()
 
     def __repr__(self):
         return f"{self.__class__.__name__}('{self._template}')"
 
+    def compile_rename_function(self):
+        """
+        Create the function that computes a new name
+
+        By creating the code dynamically, we can ensure that only those placeholder values are
+        computed that are actually used in the template.
+        """
+        code = {
+            "header": "read.name",
+            "id": "id_",
+            "comment": "comment",
+            "cut_prefix": "info.cut_prefix if info.cut_prefix else ''",
+            "cut_suffix": "info.cut_suffix if info.cut_suffix else ''",
+            "adapter_name": "info.matches[-1].adapter.name if info.matches else 'no_adapter'",
+            "rc": "'rc' if info.is_rc else ''",
+            "match_sequence": "info.matches[-1].match_sequence() if info.matches else ''",
+        }
+        placeholders = set(
+            token.value for token in self._tokens if isinstance(token, BraceToken)
+        )
+        lines = ["def rename(self, read, info):"]
+        if "id" in placeholders or "header" in placeholders:
+            lines.append("  id_, comment = self.parse_name(read.name)")
+        lines.append("  return self._template.format(")
+        for placeholder in placeholders:
+            lines.append(f"    {placeholder}={code[placeholder]},")
+        lines.append("  )")
+        logger.debug("Generated code of rename function:\n%s", "\n".join(lines))
+        namespace = dict()
+        exec("\n".join(lines), namespace)
+        return namespace["rename"]
+
     @staticmethod
     def raise_if_invalid_variable(tokens: List[Token], allowed: Set[str]) -> None:
         for token in tokens:
@@ -575,19 +584,7 @@ class Renamer(SingleEndModifier):
             return (read_name, "")
 
     def __call__(self, read: SequenceRecord, info: ModificationInfo) -> SequenceRecord:
-        id_, comment = self.parse_name(read.name)
-        read.name = self._template.format(
-            header=read.name,
-            id=id_,
-            comment=comment,
-            cut_prefix=info.cut_prefix if info.cut_prefix else "",
-            cut_suffix=info.cut_suffix if info.cut_suffix else "",
-            adapter_name=info.matches[-1].adapter.name
-            if info.matches
-            else "no_adapter",
-            rc="rc" if info.is_rc else "",
-            match_sequence=info.matches[-1].match_sequence() if info.matches else "",
-        )
+        read.name = self._rename(self, read, info)
         return read
 
 
@@ -629,42 +626,38 @@ class PairedEndRenamer(PairedEndModifier):
         info2: ModificationInfo,
     ) -> Tuple[SequenceRecord, SequenceRecord]:
 
-        id1, comment1 = Renamer.parse_name(read1.name)
-        id2, comment2 = Renamer.parse_name(read2.name)
         if not record_names_match(read1.name, read2.name):
+            id1 = Renamer.parse_name(read1.name)[0]
+            id2 = Renamer.parse_name(read1.name)[1]
             raise ValueError(f"Input read IDs not identical: '{id1}' != '{id2}'")
-        name1, name2 = self.get_new_headers(
-            id1=id1,
-            id2=id2,
-            comment1=comment1,
-            comment2=comment2,
-            header1=read1.name,
-            header2=read2.name,
-            info1=info1,
-            info2=info2,
-        )
-        new_id1 = Renamer.parse_name(name1)[0]
-        new_id2 = Renamer.parse_name(name2)[0]
+
+        name1, name2 = self._rename(read1, read2, info1, info2)
+
         if not record_names_match(name1, name2):
+            new_id1 = Renamer.parse_name(name1)[0]
+            new_id2 = Renamer.parse_name(name2)[0]
+            id1 = Renamer.parse_name(read1.name)[0]
             raise InvalidTemplate(
                 "After renaming R1 and R2, their IDs are no longer identical: "
-                "'{}' != '{}'. Original read ID: '{}'. ".format(new_id1, new_id2, id1)
+                f"'{new_id1}' != '{new_id2}'. Original read ID: '{id1}'. "
             )
         read1.name = name1
         read2.name = name2
         return read1, read2
 
-    def get_new_headers(
+    def _rename(
         self,
-        id1: str,
-        id2: str,
-        comment1: str,
-        comment2: str,
-        header1: str,
-        header2: str,
+        read1: SequenceRecord,
+        read2: SequenceRecord,
         info1: ModificationInfo,
         info2: ModificationInfo,
     ) -> Tuple[str, str]:
+
+        id1, comment1 = Renamer.parse_name(read1.name)
+        id2, comment2 = Renamer.parse_name(read2.name)
+        header1 = read1.name
+        header2 = read2.name
+
         d = []
         for id_, comment, header, info in (
             (id1, comment1, header1, info1),
