@@ -20,10 +20,9 @@ Steps are added to the pipeline in a certain order:
 from abc import ABC, abstractmethod
 from typing import Tuple, Dict, Optional, Any
 
-from .filters import Predicate
+from .predicates import Predicate
 from .modifiers import ModificationInfo
 from .statistics import ReadLengthStatistics
-from .utils import reverse_complemented_sequence
 
 # Constants used when returning from a step’s __call__ method to improve
 # readability (it is unintuitive that "return True" means "discard the read").
@@ -68,14 +67,14 @@ class SingleEndFilter(SingleEndStep):
     counts how many were filtered.
     """
 
-    def __init__(self, writer, predicate: Predicate):
+    def __init__(self, predicate: Predicate, writer):
         super().__init__()
         self.filtered = 0
-        self.writer = writer
         self.predicate = predicate
+        self.writer = writer
 
     def __repr__(self):
-        return f"SingleEndFilter(writer={self.writer}, predicate={self.predicate})"
+        return f"SingleEndFilter(predicate={self.predicate}, writer={self.writer})"
 
     def descriptive_identifier(self) -> str:
         return self.predicate.descriptive_identifier()
@@ -100,9 +99,9 @@ class PairedEndFilter(PairedEndStep):
 
     def __init__(
         self,
-        writer,
         predicate1: Optional[Predicate],
         predicate2: Optional[Predicate],
+        writer,
         pair_filter_mode="any",
     ):
         """
@@ -116,9 +115,9 @@ class PairedEndFilter(PairedEndStep):
             raise ValueError("pair_filter_mode must be 'any', 'both' or 'first'")
         self._pair_filter_mode = pair_filter_mode
         self.filtered = 0
-        self.writer = writer
         self.predicate1 = predicate1
         self.predicate2 = predicate2
+        self.writer = writer
         self._is_filtered: Any
         if predicate2 is None:
             self._is_filtered = self._is_filtered_first
@@ -133,8 +132,8 @@ class PairedEndFilter(PairedEndStep):
 
     def __repr__(self):
         return (
-            f"PairedEndFilter(writer={self.writer}, predicate1={self.predicate1}, "
-            f"predicate2={self.predicate2}, pair_filter_mode='{self._pair_filter_mode}')"
+            f"PairedEndFilter(predicate1={self.predicate1}, predicate2={self.predicate2}, "
+            f"writer={self.writer}, pair_filter_mode='{self._pair_filter_mode}')"
         )
 
     def descriptive_identifier(self) -> str:
@@ -217,7 +216,7 @@ class InfoFileWriter(SingleEndStep):
     def __call__(self, read, info: ModificationInfo):
         current_read = info.original_read
         if info.is_rc:
-            current_read = reverse_complemented_sequence(current_read)
+            current_read = current_read.reverse_complement()
         if info.matches:
             for match in info.matches:
                 for info_record in match.get_info_records(current_read):
