@@ -16,7 +16,10 @@ def test_run_cutadapt_process():
 def test_run_as_module():
     """Check that "python3 -m cutadapt ..." works"""
     from cutadapt import __version__
-    with subprocess.Popen([sys.executable, "-m", "cutadapt", "--version"], stdout=subprocess.PIPE) as py:
+
+    with subprocess.Popen(
+        [sys.executable, "-m", "cutadapt", "--version"], stdout=subprocess.PIPE
+    ) as py:
         assert py.communicate()[0].decode().strip() == __version__
 
 
@@ -27,10 +30,20 @@ def test_standard_input_pipe(tmp_path, cores):
     in_path = datapath("small.fastq")
     # Simulate that no file name is available for stdin
     with subprocess.Popen(["cat", in_path], stdout=subprocess.PIPE) as cat:
-        with subprocess.Popen([
-            sys.executable, "-m", "cutadapt", "--cores", str(cores),
-            "-a", "TTAGACATATCTCCGTCG", "-o", out_path, "-"],
-            stdin=cat.stdout
+        with subprocess.Popen(
+            [
+                sys.executable,
+                "-m",
+                "cutadapt",
+                "--cores",
+                str(cores),
+                "-a",
+                "TTAGACATATCTCCGTCG",
+                "-o",
+                out_path,
+                "-",
+            ],
+            stdin=cat.stdout,
         ) as py:
             _ = py.communicate()
             cat.stdout.close()
@@ -42,10 +55,19 @@ def test_standard_output(tmp_path, cores):
     """Write FASTQ to standard output (not using --output/-o option)"""
     out_path = os.fspath(tmp_path / "out.fastq")
     with open(out_path, "w") as out_file:
-        py = subprocess.Popen([
-            sys.executable, "-m", "cutadapt", "--cores", str(cores),
-            "-a", "TTAGACATATCTCCGTCG", datapath("small.fastq")],
-            stdout=out_file)
+        py = subprocess.Popen(
+            [
+                sys.executable,
+                "-m",
+                "cutadapt",
+                "--cores",
+                str(cores),
+                "-a",
+                "TTAGACATATCTCCGTCG",
+                datapath("small.fastq"),
+            ],
+            stdout=out_file,
+        )
         _ = py.communicate()
     assert_files_equal(cutpath("small.fastq"), out_path)
 
@@ -55,10 +77,21 @@ def test_explicit_standard_output(tmp_path, cores):
 
     out_path = os.fspath(tmp_path / "out.fastq")
     with open(out_path, "w") as out_file:
-        py = subprocess.Popen([
-            sys.executable, "-m", "cutadapt", "-o", "-", "--cores", str(cores),
-            "-a", "TTAGACATATCTCCGTCG", datapath("small.fastq")],
-            stdout=out_file)
+        py = subprocess.Popen(
+            [
+                sys.executable,
+                "-m",
+                "cutadapt",
+                "-o",
+                "-",
+                "--cores",
+                str(cores),
+                "-a",
+                "TTAGACATATCTCCGTCG",
+                datapath("small.fastq"),
+            ],
+            stdout=out_file,
+        )
         _ = py.communicate()
     assert_files_equal(cutpath("small.fastq"), out_path)
 
@@ -68,10 +101,22 @@ def test_force_fasta_output(tmp_path, cores):
 
     out_path = os.fspath(tmp_path / "out.fasta")
     with open(out_path, "w") as out_file:
-        py = subprocess.Popen([
-            sys.executable, "-m", "cutadapt", "--fasta", "-o", "-", "--cores", str(cores),
-            "-a", "TTAGACATATCTCCGTCG", datapath("small.fastq")],
-            stdout=out_file)
+        py = subprocess.Popen(
+            [
+                sys.executable,
+                "-m",
+                "cutadapt",
+                "--fasta",
+                "-o",
+                "-",
+                "--cores",
+                str(cores),
+                "-a",
+                "TTAGACATATCTCCGTCG",
+                datapath("small.fastq"),
+            ],
+            stdout=out_file,
+        )
         _ = py.communicate()
     assert_files_equal(cutpath("small.fasta"), out_path)
 
