@@ -1062,6 +1062,7 @@ def test_rename_cannot_be_combined_with_other_renaming_options(opt):
         )
 
 
+@pytest.mark.skipif(sys.platform == "win32", reason="Disabled on Windows")
 def test_duplicate_output_paths(tmp_path):
     path = str(tmp_path / "discard.fastq")
     with pytest.raises(SystemExit):
@@ -1094,7 +1095,6 @@ def test_rename(run):
     )
 
 
-@pytest.mark.skip("This has not been fixed")
 def test_terminates_correctly_on_error_in_subprocess(tmp_path):
     params = [
         "-j",
