@@ -1,12 +1,17 @@
 import typing
 
 from dnaio import Sequence
-from cutadapt.adapters import BackAdapter, AnywhereAdapter, BackAdapterStatistics, Adapter
+from cutadapt.adapters import (
+    BackAdapter,
+    AnywhereAdapter,
+    BackAdapterStatistics,
+    Adapter,
+)
 from cutadapt.modifiers import AdapterCutter, ModificationInfo
 
 
 def test_statistics() -> None:
-    read = Sequence('name', 'AAAACCCCAAAA')
+    read = Sequence("name", "AAAACCCCAAAA")
     adapters: typing.Sequence[Adapter] = [BackAdapter("CCCC", max_errors=0.1)]
     cutter = AdapterCutter(adapters, times=3)
     cutter(read, ModificationInfo(read))
@@ -26,17 +31,17 @@ def test_end_trim_with_mismatch():
     """
     adapter = BackAdapter("TCGATCGATCGAT", max_errors=0.1)
 
-    read = Sequence('foo1', 'AAAAAAAAAAATCGTCGATC')
+    read = Sequence("foo1", "AAAAAAAAAAATCGTCGATC")
     cutter = AdapterCutter([adapter], times=1)
     trimmed_read = cutter(read, ModificationInfo(read))
 
-    assert trimmed_read.sequence == 'AAAAAAAAAAA'
+    assert trimmed_read.sequence == "AAAAAAAAAAA"
     assert cutter.adapter_statistics[adapter].end.lengths == {9: 1}
     # We see 1 error at length 9 even though the number of allowed mismatches at
     # length 9 is 0.
     assert cutter.adapter_statistics[adapter].end.errors[9][1] == 1
 
-    read = Sequence('foo2', 'AAAAAAAAAAATCGAACGA')
+    read = Sequence("foo2", "AAAAAAAAAAATCGAACGA")
     cutter = AdapterCutter([adapter], times=1)
     trimmed_read = cutter(read, ModificationInfo(read))
 
@@ -47,14 +52,14 @@ def test_end_trim_with_mismatch():
 def test_anywhere_with_errors():
     adapter = AnywhereAdapter("CCGCATTTAG", max_errors=0.1)
     for seq, expected_trimmed in (
-        ('AACCGGTTccgcatttagGATC', 'AACCGGTT'),
-        ('AACCGGTTccgcgtttagGATC', 'AACCGGTT'),  # one mismatch
-        ('AACCGGTTccgcatttag', 'AACCGGTT'),
-        ('ccgcatttagAACCGGTT', 'AACCGGTT'),
-        ('ccgtatttagAACCGGTT', 'AACCGGTT'),  # one mismatch
-        ('ccgatttagAACCGGTT', 'AACCGGTT'),  # one deletion
+        ("AACCGGTTccgcatttagGATC", "AACCGGTT"),
+        ("AACCGGTTccgcgtttagGATC", "AACCGGTT"),  # one mismatch
+        ("AACCGGTTccgcatttag", "AACCGGTT"),
+        ("ccgcatttagAACCGGTT", "AACCGGTT"),
+        ("ccgtatttagAACCGGTT", "AACCGGTT"),  # one mismatch
+        ("ccgatttagAACCGGTT", "AACCGGTT"),  # one deletion
     ):
-        read = Sequence('foo', seq)
+        read = Sequence("foo", seq)
         cutter = AdapterCutter([adapter], times=1)
         trimmed_read = cutter(read, ModificationInfo(read))
         assert trimmed_read.sequence == expected_trimmed
